==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/lib/vc-dialog/DialogWrap.d.ts <==
export default DialogWrap;
declare const DialogWrap: import("vue").DefineComponent<{
    visible: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    keyboard: import("vue-types").VueTypeValidableDef<boolean>;
    mask: import("vue-types").VueTypeValidableDef<boolean>;
    afterClose: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    closable: import("vue-types").VueTypeValidableDef<boolean>;
    maskClosable: import("vue-types").VueTypeValidableDef<boolean>;
    destroyOnClose: import("vue-types").VueTypeValidableDef<boolean>;
    mousePosition: import("vue-types").VueTypeLooseShape<{
        x: number;
        y: number;
    }>;
    title: import("vue-types").VueTypeValidableDef<any>;
    footer: import("vue-types").VueTypeValidableDef<any>;
    transitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    maskTransitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    animation: import("vue-types").VueTypeValidableDef<any>;
    maskAnimation: import("vue-types").VueTypeValidableDef<any>;
    wrapStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    bodyStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    maskStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    wrapClassName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    width: import("vue-types").VueTypeDef<import("../_util/type").Key>;
    height: import("vue-types").VueTypeDef<import("../_util/type").Key>;
    zIndex: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    };
    bodyProps: import("vue-types").VueTypeValidableDef<any>;
    maskProps: import("vue-types").VueTypeValidableDef<any>;
    wrapProps: import("vue-types").VueTypeValidableDef<any>;
    getContainer: import("vue-types").VueTypeValidableDef<any>;
    dialogStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    dialogClass: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    closeIcon: import("vue-types").VueTypeValidableDef<any>;
    forceRender: import("vue-types").VueTypeValidableDef<boolean>;
    getOpenCount: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    focusTriggerAfterClose: import("vue-types").VueTypeValidableDef<boolean>;
    onClose: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, any, any, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    visible: boolean;
    transitionName: string;
    zIndex: number;
    maskTransitionName: string;
    bodyStyle: {
        [key: string]: any;
    };
    afterClose: (...args: any[]) => any;
    onClose: (...args: any[]) => any;
    maskStyle: {
        [key: string]: any;
    };
    wrapStyle: {
        [key: string]: any;
    };
    wrapClassName: string;
    dialogStyle: {
        [key: string]: any;
    };
    dialogClass: string;
    getOpenCount: (...args: any[]) => any;
} & {
    footer?: any;
    title?: any;
    mask?: boolean;
    keyboard?: boolean;
    height?: import("../_util/type").Key;
    animation?: any;
    forceRender?: boolean;
    maskClosable?: boolean;
    maskAnimation?: any;
    width?: import("../_util/type").Key;
    getContainer?: any;
    closable?: boolean;
    closeIcon?: any;
    destroyOnClose?: boolean;
    mousePosition?: {
        x: number;
        y: number;
    };
    bodyProps?: any;
    maskProps?: any;
    wrapProps?: any;
    focusTriggerAfterClose?: boolean;
}>, {
    prefixCls: string;
    visible: boolean;
    transitionName: string;
    zIndex: number;
    maskTransitionName: string;
    bodyStyle: {
        [key: string]: any;
    };
    afterClose: (...args: any[]) => any;
    onClose: (...args: any[]) => any;
    maskStyle: {
        [key: string]: any;
    };
    wrapStyle: {
        [key: string]: any;
    };
    wrapClassName: string;
    dialogStyle: {
        [key: string]: any;
    };
    dialogClass: string;
    getOpenCount: (...args: any[]) => any;
}>;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/lib/vc-dialog/DialogWrap.d.ts <==
export default DialogWrap;
declare const DialogWrap: import("vue").DefineComponent<{
    visible: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    keyboard: import("vue-types").VueTypeValidableDef<boolean>;
    mask: import("vue-types").VueTypeValidableDef<boolean>;
    afterClose: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    closable: import("vue-types").VueTypeValidableDef<boolean>;
    maskClosable: import("vue-types").VueTypeValidableDef<boolean>;
    destroyOnClose: import("vue-types").VueTypeValidableDef<boolean>;
    mousePosition: import("vue-types").VueTypeLooseShape<{
        x: (number | ((props: Record<string, unknown>) => number)) & number;
        y: (number | ((props: Record<string, unknown>) => number)) & number;
    }>;
    title: import("vue-types").VueTypeValidableDef<any>;
    footer: import("vue-types").VueTypeValidableDef<any>;
    transitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    maskTransitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    animation: import("vue-types").VueTypeValidableDef<any>;
    maskAnimation: import("vue-types").VueTypeValidableDef<any>;
    wrapStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    bodyStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    maskStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    wrapClassName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    width: import("vue-types").VueTypeDef<string | number>;
    height: import("vue-types").VueTypeDef<string | number>;
    zIndex: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    };
    bodyProps: import("vue-types").VueTypeValidableDef<any>;
    maskProps: import("vue-types").VueTypeValidableDef<any>;
    wrapProps: import("vue-types").VueTypeValidableDef<any>;
    getContainer: import("vue-types").VueTypeValidableDef<any>;
    dialogStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    dialogClass: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    closeIcon: import("vue-types").VueTypeValidableDef<any>;
    forceRender: import("vue-types").VueTypeValidableDef<boolean>;
    getOpenCount: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    focusTriggerAfterClose: import("vue-types").VueTypeValidableDef<boolean>;
    onClose: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, any, any, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    visible: boolean;
    transitionName: string;
    zIndex: number;
    maskTransitionName: string;
    bodyStyle: {
        [key: string]: any;
    };
    afterClose: (...args: any[]) => any;
    onClose: (...args: any[]) => any;
    maskStyle: {
        [key: string]: any;
    };
    wrapStyle: {
        [key: string]: any;
    };
    wrapClassName: string;
    dialogStyle: {
        [key: string]: any;
    };
    dialogClass: string;
    getOpenCount: (...args: any[]) => any;
} & {
    footer?: any;
    title?: any;
    mask?: boolean;
    keyboard?: boolean;
    height?: string | number;
    width?: string | number;
    animation?: any;
    forceRender?: boolean;
    maskClosable?: boolean;
    maskAnimation?: any;
    closable?: boolean;
    getContainer?: any;
    closeIcon?: any;
    destroyOnClose?: boolean;
    mousePosition?: {
        x: (number | ((props: Record<string, unknown>) => number)) & number;
        y: (number | ((props: Record<string, unknown>) => number)) & number;
    };
    bodyProps?: any;
    maskProps?: any;
    wrapProps?: any;
    focusTriggerAfterClose?: boolean;
}>, {
    prefixCls: string;
    visible: boolean;
    transitionName: string;
    zIndex: number;
    maskTransitionName: string;
    bodyStyle: {
        [key: string]: any;
    };
    afterClose: (...args: any[]) => any;
    onClose: (...args: any[]) => any;
    maskStyle: {
        [key: string]: any;
    };
    wrapStyle: {
        [key: string]: any;
    };
    wrapClassName: string;
    dialogStyle: {
        [key: string]: any;
    };
    dialogClass: string;
    getOpenCount: (...args: any[]) => any;
}>;
